==> react-ui-library-0.13.15.tgz: package/src/collapsible/collapsible.js <==
/* eslint-disable react/no-set-state, react/no-did-mount-set-state */
import React, { cloneElement, Component } from 'react';
import PropTypes from 'prop-types';

const transitionTime = 400;

/**
 * Collapsible
 */
export default class Collapsible extends Component {

  /**
   * Constructor
   * @param {Object} props - React props
   */
  constructor(props) {
    super(props);
    this.state = { style: {} };
  }

  /**
   * Right when mounted measure the content's height
   */
  componentDidMount() {
    this.height = this.getHeight();
    this.setState({
      style: {
        height: this.props.collapsed ? 0 : this.height,
        overflow: this.props.collapsed ? 'hidden' : 'visible'
      }
    });
  }

  /**
   * When collapsing changes reset the content's height
   * @param {object} nextProps - Next props
   */
  componentWillReceiveProps(nextProps) {
    if (nextProps.collapsed !== this.props.collapsed && !this.updating) {
      this.toggleCollapse(nextProps.collapsed);
    }
  }

  /**
   * If content changes reset the content's height
   */
  componentDidUpdate() {
    if (this.height !== this.getHeight() && !this.updating) {
      this.height = this.getHeight();
      this.toggleCollapse(this.props.collapsed);
    }
  }

  /**
   * Collapse or uncollapse
   * changing height and overflow
   * @param {boolean} collapsed - True if it's collapsed
   */
  toggleCollapse(collapsed) {
    this.updating = true;
    this.setState({
      style: {
        height: collapsed ? 0 : this.height,
        transition: `height ${transitionTime / 1000}s ease-out`,
        overflow: 'hidden'
      }
    });

    setTimeout(() => {
      this.setState({
        style: {
          height: collapsed ? 0 : this.getHeight(),
          overflow: collapsed ? 'hidden' : 'visible'
        }
      });
      this.updating = false;
    }, transitionTime);
  }

  // istanbul ignore next
  /**
   * Measure content's height
   * @returns {string} - Height in pixels
   */
  getHeight() {
    return this._content.getBoundingClientRect().height;
  }

  /**
   * Render method
   * @returns {JSX} - Component template
   */
  render() {

    const
      { children } = this.props,
      { style } = this.state,
      child = cloneElement(children, {
        ...children.props,
        ref: content => { this._content = content; }
      });

    return <div className="collapsible" style={ style }>{ child }</div>;
  }
}

Collapsible.propTypes = {
  children: PropTypes.element,
  collapsed: PropTypes.bool
};

==> react-ui-library-0.13.21.tgz: package/src/collapsible/collapsible.js <==
/* eslint-disable react/no-did-mount-set-state */
import React, { cloneElement, Component } from 'react';
import PropTypes from 'prop-types';

const transitionTime = 400;

/**
 * Collapsible
 */
export default class Collapsible extends Component {

  /**
   * Constructor
   * @param {Object} props - React props
   */
  constructor(props) {
    super(props);
    this.state = { style: {} };
  }

  /**
   * Right when mounted measure the content's height
   */
  componentDidMount() {
    this.height = this.getHeight();
    this.setState({
      style: {
        height: this.props.collapsed ? 0 : this.height,
        overflow: this.props.collapsed ? 'hidden' : 'visible',
      },
    });
  }

  /**
   * When collapsing changes reset the content's height
   * @param {object} nextProps - Next props
   */
  componentWillReceiveProps(nextProps) {
    if (nextProps.collapsed !== this.props.collapsed && !this.updating) {
      this.toggleCollapse(nextProps.collapsed);
    }
  }

  /**
   * If content changes reset the content's height
   */
  componentDidUpdate() {
    if (this.height !== this.getHeight() && !this.updating) {
      this.height = this.getHeight();
      this.toggleCollapse(this.props.collapsed);
    }
  }

  // istanbul ignore next
  /**
   * Measure content's height
   * @returns {string} - Height in pixels
   */
  getHeight() {
    return this.content.getBoundingClientRect().height;
  }

  /**
   * Collapse or uncollapse
   * changing height and overflow
   * @param {boolean} collapsed - True if it's collapsed
   */
  toggleCollapse(collapsed) {
    this.updating = true;
    this.setState({
      style: {
        height: collapsed ? 0 : this.height,
        transition: `height ${transitionTime / 1000}s ease-out`,
        overflow: 'hidden',
      },
    });

    setTimeout(() => {
      this.setState({
        style: {
          height: collapsed ? 0 : this.getHeight(),
          overflow: collapsed ? 'hidden' : 'visible',
        },
      });
      this.updating = false;
    }, transitionTime);
  }

  /**
   * Render method
   * @returns {JSX} - Component template
   */
  render() {
    const { children } = this.props;
    const { style } = this.state;
    const child = cloneElement(children, {
      ...children.props,
      ref: (content) => { this.content = content; },
    });

    return <div className="collapsible" style={style}>{ child }</div>;
  }
}

Collapsible.propTypes = {
  children: PropTypes.element,
  collapsed: PropTypes.bool,
};
